@@ -523,6 +523,24 @@ function getMostRecentMailWindow() {
   return win;
 }
 
+/**
+ * Create a sanitized display name for an attachment in order to help prevent
+ * people from hiding malicious extensions behind a run of spaces, etc. To do
+ * this, we strip leading/trailing whitespace and collapse long runs of either
+ * whitespace or identical characters. Windows especially will drop trailing
+ * dots and whitespace from filename extensions.
+ *
+ * @param aAttachment the AttachmentInfo object
+ * @return a sanitized display name for the attachment
+ */
+function SanitizeAttachmentDisplayName(aAttachment)
+{
+  let displayName = aAttachment.name.trim();
+  return displayName.replace(/\s+/g, " ")
+//@line 598 "/export/home/mozilla/packages/BUILD/SFWthunderbird/comm-release/mail/base/content/mailCore.js"
+                    .replace(/(.)\1{9,}/g, "$1…$1");
+}
+
 /**
  * Create a TransferData object for a message attachment, either from the
  * message reader or the composer.
@@ -606,7 +624,8 @@ nsFlavorDataProvider.prototype =
       // call our code for saving attachments
       if (attachment)
       {
-        var destFilePath = messenger.saveAttachmentToFolder(attachment.contentType, attachment.url, encodeURIComponent(attachment.displayName), attachment.uri, destDirectory);
+        var name = attachment.name || attachment.displayName;
+        var destFilePath = messenger.saveAttachmentToFolder(attachment.contentType, attachment.url, encodeURIComponent(name), attachment.uri, destDirectory);
         aData.value = destFilePath.QueryInterface(Components.interfaces.nsISupports);
         aDataLen.value = 4;
       }
